# JobType

Data Backfill job type

## Enum

* `PRODUCTRATEPLANCHARGE` (value: `'ProductRatePlanCharge'`)

* `RATEPLANCHARGE` (value: `'RatePlanCharge'`)

* `INVOICEDETAIL` (value: `'InvoiceDetail'`)

* `MEMODETAIL` (value: `'MemoDetail'`)

* `INVOICEITEMADJUSTMENT` (value: `'InvoiceItemAdjustment'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


